var NativeBase = /** @class */ (function () {
    function NativeBase() {
        this.version = 31;
        this.listeners = []; //TODO:实现多个listener
        this.topicPtMap = new Set();
    }
    NativeBase.prototype.init = function () {
        this.register();
    };
    NativeBase.prototype.register = function () {
        console.log("native", "register");
        var self = this;
        cc.director.notificationJsGame = function (eventName, data) {
            self.dispatchNotification(eventName, data);
        };
    };
    NativeBase.prototype.notificationNative = function (identifier, parameter) {
        var body = JSON.stringify({
            identifier: identifier,
            parameter: parameter
        });
        // console.log(`cc.native.notificationNative ${body}`);
        cc.director.notificationNative("CocosInteractiveWithNative", body);
    };
    NativeBase.prototype.dispatchNotification = function (eventName, data) {
        if (eventName == "COCOS_GAME_START") {
            var gameName = data.gameName;
            var uid = data.uid;
            var roomId = data.roomId;
            var matchId = data.matchId;
            var avatar = data.avatar;
            var mqttTopic = data.mqttTopic;
            cc.uid = uid;
            cc.toUid = data.toUid;
            cc.mqttTopic = mqttTopic;
            cc.avatar = avatar;
            cc.gameName = gameName;
            cc.roomId = roomId;
            cc.matchId = matchId || roomId;
            cc.name = data.name;
            cc.soundOn = data.soundOn;
            cc.notch = data.notch;
            cc.soundSwitch = {
                liveSwitch: data.liveSwitch || 0,
                liveVol: data.liveVol || 0,
                musicSwitch: data.musicSwitch || 0,
                musicVol: data.musicVol || 0,
                effectSwitch: data.effectSwitch || 0,
            };
            cc.dependPluginList = data.dependPluginList;
            cc.ext = data.ext && JSON.parse(data.ext);
            cc.gameTypeId = data.gameTypeId;
            cc.gameSubTypeId = data.gameSubTypeId;
            cc.platformVersion = data.platformVersion;
            cc.director.loadScene('main', function () {
            });
        }
        else if (eventName == "MQTT_PRIVATE_RECEIVED") {
            this.onPrivateMqttMsg(data);
        }
        else if (eventName == "HTTP_RESPONSE") {
            this.onHttpResponse(data);
        }
        else if (eventName == "COCOS_GAME_MQTT_ERROR") {
            this.onMqttError(data);
        }
        else if (eventName == "COCOS_GAME_RESUME") {
            this.onGameResume(data);
        }
        else if (eventName == "COCOS_GAME_STOP") {
            this.onGameStop(data);
        }
        else if (eventName == "COCOS_GAME_RECHARGE_SUCCESS") {
            this.onRechargeSuccess(data);
        }
        else if (eventName == "COCOS_GAME_MQTT_STATE_CHANGE") {
            this.onMqttStateChange(data);
        }
        else if (eventName == "ROOM_SOUND_SWITCH_ON") {
            data.soundOn = true;
            this.onRoomSoundSwitch(data);
        }
        else if (eventName == "ROOM_SOUND_SWITCH_OFF") {
            data.soundOn = false;
            this.onRoomSoundSwitch(data);
        }
        else if (eventName == "COCOS_ROOM_SOUND_SWITCH_TO_JS") {
            this.onRoomSoundSwitchToJs(data);
        }
        else if (eventName == "COCOS_PING_FINISH") {
            this.onPingFinish(data);
        }
        else if (eventName == "COCOS_ROOM_CHAT") {
            this.onRoomChat(data);
        }
        else if (eventName == "COCOS_RESET_SOUND") {
            this.onResetSound(data);
        }
        else if (eventName == "COCOS_LIVE_VOICE_VOLUME") {
            this.onLiveVoiceVolume(data);
        }
        else if (eventName == "COCOS_CHECK_MIC_AUTHORITY_RESPONSE") {
            this.onMicAuthorityResponse(data);
        }
        else if (eventName == "COCOS_GAME_KICK_GAME") {
            this.removeListener();
            cc.director.loadScene("quit");
        }
        else if (eventName == "COCOS_GAME_EXCHANGE") {
            this.onExchange(data);
        }
        else if (eventName == "COCOS_GAME_KEYBOARD_INPUT") {
            this.onKeyboardInput(data);
        }
        else if (eventName == "COCOS_USERINFO_PANEL_CLOSE") {
            this.onUserInfoPanelClose(data);
        }
        else if (eventName == "NATIVE_CLOSE_GIFT_PANEL") {
            this.onNativeCloseGiftPanel(data);
        }
        else if (eventName == "COCOS_ON_GET_BATCH_FRIEND") {
            this.onGetBatchFriend(data);
        }
        else if (eventName == "ON_GET_NATIVE_GLOBAL_CONFIG") {
            this.onGetNativeGlobalConfig(data);
        }
        else if (eventName == "COCOS_SAVE_FILE_TO_CDN_RESULT") {
            this.saveFileToCDNResult(data);
        }
        else if (eventName == "COCOS_CHANGE_HOST_PORT_RESULT") {
            this.onChangeMqttHostPortResult(data);
        }
        else if (eventName == "COCOS_GET_H5_TICKET") {
            this.onGetH5Ticket(data);
        }
        else if (eventName == "COCOS_CHAT_SELECTOR_RESULT") {
            this.onGetSelectorResult(data);
        }
        else if (eventName == "COCOS_SEND_PRIVATE_CHAT_RESULT") {
            this.onGetPrivateChatResult(data);
        }
        else if (eventName == "COCOS_LIVE_VOICE_JOIN_ROOM_RESULT") {
            this.onJoinLiveVoiceRoomResult(data);
        }
        else if (eventName == "COCOS_LIVE_VOICE_QUIT_ROOM_RESULT") {
            this.onQuitLiveVoiceRoomResult(data);
        }
        else if (eventName == "COCOS_GET_KEYBOARD_RES") {
            this.onGetKeyboardRes(data);
        }
        else if (eventName == "COCOS_SCENESHORTCUTPAY_RESULT") {
            this.onGetSceneShortCutPayRes(data);
        }
        else if (eventName == "COCOS_GETABTESTCONFIG_RESULT") {
            this.onGetABTestConfigRes(data);
        }
        else if (eventName == "COCOS_CLICKBARRAGE_RESULT") {
            this.onClickBarrageRes(data);
        }
        else if (eventName == "H5_CLOSED_IN_GAME") {
            this.onH5CloseInGame(data);
        }
        else if (eventName == "H5_TO_COCOS_MESSAGE") {
            this.onH5ToCocosMessage(data);
        }
        else {
            console.log("Warning, Native !-------------------- No Handler With:", eventName);
        }
    };
    /**
     @description 注销原生监听
     */
    NativeBase.prototype.unregister = function () {
        cc.director.notificationJsGame = null;
    };
    /**
     @description
     */
    NativeBase.prototype.addListener = function (listener) {
        console.log("mqtt addListener", listener == null);
        this.listeners.push(listener);
    };
    /**
     @description 移除监听者
     */
    NativeBase.prototype.removeListener = function () {
        this.listeners.splice(0, this.listeners.length);
    };
    NativeBase.prototype.onQuitGame = function () {
        var _this = this;
        console.log("native", "onQuitGame");
        //退出游戏时,自动注销所有topic
        this.topicPtMap.forEach(function (topic) {
            _this.mqttUnsubscribePrivate(topic);
        });
        this.topicPtMap.clear();
        cc.unSetConstructors();
        cc.PackDownloader.reset();
        cc.loader.releaseAll();
        cc.sys.cleanScript(cc.gameName + "/src/project.js");
        cc.sys.cleanScript(cc.gameName + "/src/settings.js");
        cc.unloadScripts();
        cc.sys.garbageCollect();
    };
    /**
     @description 订阅mqtt
     */
    NativeBase.prototype.mqttSubscribePrivate = function (topic, cmd) {
        console.log("native", "mqttSubscribePrivate", topic, cmd);
        this.notificationNative("SubscribeMQTT", { topic: topic });
    };
    /**
     @description 退订阅mqtt
     */
    NativeBase.prototype.mqttUnsubscribePrivate = function (topic, cmd) {
        console.log("native", "subscribeMqtt", topic);
        this.notificationNative("UnsubscribeMQTT", { topic: topic });
    };
    //CallNative------------------------------------------------------------
    /**
     @description 退出游戏,大多数情况下直接调用 cc.native.quitGame();
     @param liveVoiceOpened 当前实时语音开关状态 liveVoiceRoomId
     //TODO:参数类型 问一下耀建 ？？？？
     */
    NativeBase.prototype.quitGame = function (liveVoiceOpened, liveVoiceRoomId, stepType, isInviter) {
        console.log("native", "quitGame");
        this.onQuitGame();
        this.notificationNative("QuitGame", liveVoiceOpened === undefined ? {} : {
            liveVoiceOpened: liveVoiceOpened,
            liveVoiceRoomId: liveVoiceRoomId,
            stepType: stepType,
            isInviter: isInviter
        });
    };
    /**
     @description 退出游戏 //TODO 只有怼法官在用
     */
    NativeBase.prototype.backRoom = function (roomId) {
        console.log("native", "backRoom");
        this.onQuitGame();
        this.notificationNative("BackRoom", {
            roomId: roomId
        });
    };
    /**
     @description 更换roomId
     */
    NativeBase.prototype.changeRoomId = function (roomId) {
        console.log("native", "changeRoomId");
        this.notificationNative("ChangeRoomId", {
            roomId: roomId,
        });
    };
    /**
     @description 重置音效接口 //TODO:avalon在用 好像是个按钮
     */
    NativeBase.prototype.resetSound = function () {
        console.log("native", "resetSound");
        this.notificationNative("ResetSound", {
            roomId: cc.roomId,
        });
    };
    /**
     @description 好友邀请
     @param type 1表示"口令+海报"方式的邀请；0或者不设置type字段，表示默认的老版本的原生分享弹窗
     */
    NativeBase.prototype.inviteFirend = function (type) {
        console.log("native", "inviteFirend");
        this.notificationNative("ShowInviteFriend", {
            type: !type ? 0 : type,
        });
    };
    /**
     @description 调起原生群邀请
     */
    NativeBase.prototype.inviteGroup = function () {
        console.log("native", "inviteGroup");
        this.notificationNative("InviteGroup", {});
    };
    /**
     @description 关闭原生群邀请面板
     */
    NativeBase.prototype.closeInviteGroupPanel = function () {
        console.log("native", "closeInviteGroupPanel");
        this.notificationNative("CloseInviteGroup", {});
    };
    /**
     @description 通知原生要获取好友列表
     */
    NativeBase.prototype.getBatchFriend = function (data) {
        console.log("native", "getBatchFriend ", data);
        this.notificationNative("GetBatchFriend", data);
    };
    /**
     @description 设置实时语音麦克开关
     */
    NativeBase.prototype.liveVoiceEnableSpeaker = function (enable) {
        console.log("native", "liveVoiceEnableSpeaker", enable);
        this.notificationNative("SetLiveVoiceSpeakerEnable", {
            enable: enable,
        });
    };
    /**
     @description 加入实时语音房间
     */
    NativeBase.prototype.liveVoiceJoinRoom = function (roomId, interval) {
        if (interval === void 0) { interval = 300; }
        console.log("native", "liveVoiceJoinRoom", roomId, interval);
        this.notificationNative("JoinLiveVoiceRoom", {
            roomId: roomId,
            interval: interval,
        });
    };
    /**
     @description 退出实时语音房间
     */
    NativeBase.prototype.liveVoiceQuitRoom = function (roomId, liveVoiceOpened) {
        console.log("native", "liveVoiceQuitRoom", roomId, liveVoiceOpened);
        this.notificationNative("QuitLiveVoiceRoom", {
            roomId: roomId,
            liveVoiceOpened: liveVoiceOpened
        });
    };
    /**
     @description 是否ban所有人语音
     */
    NativeBase.prototype.liveVoiceBanAll = function (ban) {
        console.log("native", "liveVoiceBanAll", "ban: " + ban);
        this.notificationNative("BanAllLiveVoice", {
            ban: ban ? 1 : 0
        });
    };
    /**
     @description 是否ban单个人语音
     */
    NativeBase.prototype.liveVoiceBanWithUid = function (uid, ban) {
        console.log("native", "liveVoiceBanWithUid", "uid: " + uid + ", ban: " + ban);
        this.notificationNative("BanLiveVoiceWithUid", {
            uid: uid,
            ban: ban ? 1 : 0
        });
    };
    /**
     @description 显示聊天
     */
    NativeBase.prototype.showRoomChat = function (channel, clean) {
        console.log("native", "showRoomChat", channel, clean);
        this.notificationNative("ShowRoomChat", {
            channel: channel || 0,
            clean: clean || 0,
        });
    };
    /**
     @description 隐藏聊天
     */
    NativeBase.prototype.hideRoomChat = function () {
        console.log("native", "hideRoomChat");
        this.notificationNative("HideRoomChat", {});
    };
    /**
     @description 改变聊天数据格式,发弹幕还是聊天气泡,或者其他
     */
    NativeBase.prototype.changeChatMsgConf = function (displayType) {
        console.log("native", "changeChatMsgConf", displayType);
        this.notificationNative("ChangeChatConfig", { displayType: displayType || 1 });
    };
    /**
     @description 显示弹幕
     {
         "backColor" : "", // 弹幕背景色, 默认透明
         "color" : "#FFFFFF", // 弹幕文本颜色, 默认黑色
         "message" : "弹幕内容", // 弹幕文本内容
         "position" : 1, //位置, 默认0;
         "showAvatar" : 1, //是否显示头像, 没有此字段时, 不显示头像
         "showUsername" : 1, // 是否显示昵称, 没有此字段时, 不显示昵称
         "size" : 16, // 弹幕字体大小; 默认14
         "style" : 0, // 显示样式: 0=名字和内容是上下结构的显示样式, 1=名字和内容是左右结构的显示样式,  默认0
         "time" : 5, // 默认5秒显示完
         "uid" : "70735353",
         "userIcon" : "http://qiniu.wodidashi.com/head/QoT0QhaUQUYBu?imageView/2/w/200/h/200", // 没时,不显示头像
         "username" : "10791uu", // 没有时, 不显示弹幕
         "usernameColor" : "#FFCF17", // 没有时, 不显示弹幕
         "vipLevel" : 2 // vip标记, 默认不显示
     }

     */
    NativeBase.prototype.showDanMu = function (uid, username, userIcon, message, style) {
        console.log("native", "showDanMu");
        var body = {
            uid: uid,
            username: username,
            userIcon: userIcon,
            message: message
        };
        body.backColor = "";
        body.color = "#FFFFFF";
        body.position = 0;
        body.showAvatar = 1;
        body.showUsername = 1;
        body.size = 14;
        body.style = 0;
        body.time = 5;
        body.usernameColor = "#FFCF17";
        body.vipLevel = 0;
        if (style) {
            for (var key in style) {
                body[key] = style[key];
            }
        }
        this.notificationNative("ShowBarrage", body);
    };
    /**
     @description 显示私聊键盘
     */
    NativeBase.prototype.showPrivateChatKeyboard = function (uid, username, placeHolder) {
        console.log("native", "showPrivateChatKeyboard", uid, username, placeHolder);
        this.showKeyboard(2, 0, { uid: uid, username: username, placeholder: placeHolder });
    };
    /**
     @description 显示键盘 TODO:参数类型 与上面统一
     */
    NativeBase.prototype.showKeyboard = function (channel, clean, body) {
        console.log("native", "showKeyboard", channel, clean);
        this.notificationNative("ShowKeyboard", {
            channel: channel || 0,
            clean: clean || 0,
            body: body
        });
    };
    /**
     @description 设置可用键盘
     */
    NativeBase.prototype.enableKeyboard = function (enable) {
        console.log("native", "enableKeyboard", enable);
        this.notificationNative("SetKeyboardEnable", {
            enable: enable
        });
    };
    /**
     @description 隐藏键盘
     */
    NativeBase.prototype.hideKeyboard = function () {
        console.log("native", "hideKeyboard");
        this.notificationNative("HideKeyboard", {});
    };
    /**
     @description 弹出用户信息界面
     */
    NativeBase.prototype.showUserInfoView = function (userId, avatarUrl) {
        console.log("native", "showUserInfoView", userId);
        this.notificationNative("PresentUserInfo", {
            userId: userId,
            userIcon: avatarUrl,
        });
    };
    /**
     @description 弹出投诉页面
     */
    NativeBase.prototype.showGameReport = function (toUid) {
        console.log("native", "showGameReport", toUid);
        this.notificationNative("GameReport", {
            toUid: toUid,
        });
    };
    /**
     @description 获取 ABTestConfig
     */
    NativeBase.prototype.getABTestConfig = function (key) {
        console.log("native", "getABTestConfig key ", key);
        this.notificationNative("GetABTestConfig", {
            key: key
        });
    };
    /**
     @description 场景快捷支付
        version 号 等于  21
            sceneShortCutPay(scene : string , diffCount : number,detail :  string,source :  string)

        version 号 大于等于  22
            sceneShortCutPay(scene : string , diffCount : number,detail :  string,source :  string,costType : number)
        
        version 号 大于等于  23
            sceneShortCutPay(scene : string , diffCount : number,detail :  string,source :  string,costType : number,gameSubType: string)

        version 号 大于等于  24
            sceneShortCutPay(scene : string , diffCount : number,detail :  string,source :  string,costType : number,gameSubType: string, duration: number)
     */
    NativeBase.prototype.sceneShortCutPay = function (scene, diffCount, detail, source, costType, gameSubType, duration) {
        console.log("native", "sceneShortCutPay scene ", scene, "  diffCount ", diffCount, "  costType ", costType, "  gameSubType", gameSubType, " duration", duration);
        this.notificationNative("SceneShortCutPay", {
            scene: scene,
            diffCount: diffCount,
            detail: detail,
            source: source,
            costType: costType,
            gameSubType: gameSubType,
            duration: duration
        });
    };
    /**
     * @description Cocos日志上报
     * @param logInfo log信息
     * @param logLevel log等级,info,error
     */
    NativeBase.prototype.logReport = function (logInfo, logLevel) {
        console.log("native", "logReport clientType cocos logInfo ", logInfo, " logLevel ", logLevel);
        this.notificationNative("LogReport", {
            clientType: "cocos",
            logInfo: logInfo,
            logLevel: logLevel
        });
    };
    /**
     @description @一个用户
     */
    NativeBase.prototype.atUser = function (userName) {
        console.log("native", "atUser", userName);
        this.notificationNative("AtSomebody", { userName: userName });
    };
    /**
     @description 送花面板
     */
    NativeBase.prototype.showSendRosePanel = function (uid) {
        console.log("native", "showSendRosePanel", uid);
        this.notificationNative("SendRoseToUser", { uid: uid });
    };
    /**
     @description 弹出充值商城界面
     */
    NativeBase.prototype.showRechargeView = function () {
        console.log("native", "showRechargeView");
        this.nativeRouter("wanba://shopcenter/enter");
    };
    /**
     @description 弹出排行榜界面
     */
    NativeBase.prototype.showRankView = function () {
        console.log("native", "showRankView");
        this.nativeRouter("wanba://rank/enter");
    };
    /**
     @description 弹出历史界面
     */
    NativeBase.prototype.showHistoryView = function (gameName) {
        console.log("native", "showHistoryView", gameName);
        this.notificationNative("PresentHistory", {
            gameName: gameName,
        });
    };
    /**
     @description 弹出帮助界面
     */
    NativeBase.prototype.showHelpView = function (gameName, url, title) {
        console.log("native", "showHelpView", gameName);
        this.notificationNative("PresentHelp", {
            gameName: gameName,
            url: url,
            title: title,
        });
    };
    /**
     @description 弹出设置界面
     */
    NativeBase.prototype.showRoomSettingView = function (roomId) {
        console.log("native", "showRoomSettingView", roomId);
        this.notificationNative("ShowRoomSetting", {
            roomId: roomId,
        });
    };
    /**
     @description 弹出提示
     */
    NativeBase.prototype.showAlertView = function (context, btnText, title) {
        console.log("native", "showAlertView", context, btnText, title);
        this.notificationNative("PresentAlert", {
            context: context,
            btnText: btnText,
            title: title,
        });
    };
    /**
     @description 弹出提示
     */
    NativeBase.prototype.showToastView = function (text) {
        console.log("native", "showToastView", text);
        this.notificationNative("PresentToast", {
            text: text,
        });
    };
    /**
     @description 发http
     */
    NativeBase.prototype.sendHttp = function (url, sign, data) {
        console.log("native", "sendHttp", url, data);
        this.notificationNative("SendHTTP", {
            path: url,
            sign: sign,
            param: data || {},
        });
    };
    /**
 @description 发mqtt
 */
    NativeBase.prototype.sendMqtt = function (topic, cmd, data) {
        console.log("native", "sendMqtt", topic, cmd, JSON.stringify(data));
        this.notificationNative("SendMQTTMessage", {
            topic: (topic && topic[0] == "/") ? topic : ("/" + topic + "/c2s"),
            cmd: cmd,
            message: JSON.stringify(data)
        });
    };
    /**
     @description
     */
    NativeBase.prototype.startPing = function () {
        console.log("native", "startPing");
        this.notificationNative("StartPing", {});
    };
    /**
     @description 好友分享
     */
    NativeBase.prototype.showShare = function (jsonData) {
        console.log("native", "share", JSON.stringify(jsonData));
        this.notificationNative("ShowShare", jsonData);
    };
    /**
     @description 隐藏加载界面
     */
    NativeBase.prototype.hideLoading = function () {
        console.log("native", "hideLoading");
        this.notificationNative("HideLoading", {});
        if (cc.flag_show_version) {
            this.showGameVersion();
        }
    };
    NativeBase.prototype.showGameVersion = function () {
        var versionfile = JSON.parse(jsb.fileUtils.getStringFromFile(cc.gameName + '/version.json'));
        var version = versionfile["version"];
        cc.native.showToastView("Version:" + version);
    };
    /**
     @description 音效音乐接口 和 声网语音大小控制
     */
    NativeBase.prototype.roomSoundSwitch = function (data) {
        console.log("native", "roomSoundSwitch");
        data = data || {};
        data.liveSwitch = data.liveSwitch || 0; //实时语音开关
        data.liveVol = data.liveVol || 0; //0-100 ? 实时语音音量
        data.musicSwitch = data.musicSwitch || 0; //1-0 音乐开关
        data.musicVol = data.musicVol || 0; //0-100 ? 音乐音量
        data.effectSwitch = data.effectSwitch || 0; //1-0 音效开关
        this.notificationNative("RoomSoundSwitch", {
            data: data,
        });
    };
    /**
     @description Cocos报错提交日志 和 打点接口
     */
    NativeBase.prototype.remoteLog = function (params) {
        console.log("native", "remoteLog");
        this.notificationNative("RemoteLog", params);
    };
    /**
     @description Cocos报错提交日志 和 打点接口 新的，可以
     @param event 总事件名 extraInfo为参数
     */
    NativeBase.prototype.triggerTrackPoint = function (event, extraInfo) {
        console.log("native", "triggerTrackPoint");
        this.notificationNative("TriggerTrackPoint", {
            event: event,
            extraInfo: extraInfo
        });
    };
    /**
     @description 查询语音权限
     */
    NativeBase.prototype.checkMicAuthorityRequest = function () {
        console.log("native", "checkMicAuthorityRequest");
        this.notificationNative("CheckMICAuthority", {});
    };
    /**
     @description 获取麦克风权限请求
     */
    NativeBase.prototype.checkRequireMicAuthority = function () {
        console.log("native", "checkRequireMicAuthority");
        this.notificationNative("RequestMICAuthority", {});
    };
    /**
     @description 保存到系统相册
     */
    NativeBase.prototype.saveToAlbum = function (path) {
        console.log("native", "saveToAlbum");
        this.notificationNative("SaveToAlbum", {
            imagePath: path
        });
    };
    /**
     @description 点歌
     */
    NativeBase.prototype.showPlayMusic = function () {
        console.log("native", "showPlayMusic");
        this.notificationNative("ShowPlayMusic", {});
    };
    /**
     * @description 调出礼物面板
     * @param clickUserInfo 点击的那个玩家的数据
     * @param allPlayers 座位上的其他玩家数据的数组，最好按照座位号排序； version 大等于 29
     */
    NativeBase.prototype.showGiftPanel = function (clickUserInfo, allPlayers) {
        console.log("native", "showGiftPanel");
        this.notificationNative("ShowGiftPanel", {
            clickUserInfo: clickUserInfo,
            allPlayers: allPlayers && allPlayers.length ? allPlayers : [],
        });
    };
    /**
     @description 关闭礼物面板
     */
    NativeBase.prototype.closeGiftPanel = function () {
        console.log("native", "closeGiftPanel");
        this.notificationNative("CloseGiftPanel", {});
    };
    /**
     @description
        path 设置分享图片路径
        shareSource 为数字

        version 21 以上添加的
            unifiedJump 统一跳转
                参考链接 http://wiki.wb-intra.com/pages/viewpage.action?pageId=5637929
            analysisName  埋点关联名称， 比如pet
            imageUrl  关联的url,用于UI显示
            title  关联的文本,imageUrl为空时，使用文本
        
     */
    NativeBase.prototype.shareImagePath = function (path, shareSource, unifiedJump, analysisName, imageUrl, title) {
        console.log("native", "shareImagePath ", path, shareSource);
        this.notificationNative("ShareMiniGame", {
            imagePath: path,
            shareSource: shareSource,
            unifiedJump: unifiedJump,
            analysisName: analysisName,
            imageUrl: imageUrl,
            title: title
        });
    };
    /**
     @description 获取原生remoteConfig中key的值
     */
    NativeBase.prototype.getNativeGlobalConfig = function (key) {
        console.log("native", "getNativeGlobalConfig ");
        this.notificationNative("GetNativeGlobalConfigWithKey", {
            key: key
        });
    };
    /**
     @description 加好友
     */
    NativeBase.prototype.addFriend = function (data) {
        console.log("native", "addFriend ", JSON.stringify(data));
        this.notificationNative("AddFriend", data);
    };
    /**
     @description 统一跳转
     */
    NativeBase.prototype.nativeRouter = function (routerPath) {
        console.log("native", "nativeRouter ");
        this.notificationNative("NativeRouter", {
            routerPath: routerPath,
        });
    };
    /**
     * @description 保存文件到CDN
     建议格式 gamename/uid/function_timestamp
     mahjong/2003001/screenshots_1536207946607
     */
    NativeBase.prototype.saveFileToCDN = function (filePath, cdnPath) {
        console.log("native", "saveFileToCDN ");
        this.notificationNative("SaveFileToCDN", {
            filePath: filePath,
            cdnPath: cdnPath,
        });
    };
    /**
     @description 通知原生更换mqtt连接服务端地址
     */
    NativeBase.prototype.changeMqttHostPort = function (host, port, bizType, topic, keepAlive) {
        console.log("native", "changeMqttHostPort");
        this.notificationNative("ChangeMQTTPort", {
            host: host,
            port: port,
            bizType: bizType,
            topic: topic,
            keepAlive: keepAlive,
        });
    };
    /**
     @description 调起原生私聊选择器
     type :   // "recent" 最近联系 , "friend" 好友, "group" 群聊, "sceneId" 场景id 随着业务value值会不同，服务端来确定
     value : 1 // 0不包含群聊 , 1包含群聊 只在recent里有用, 在场景sceneId里服务端来确定
     */
    NativeBase.prototype.chatSelector = function (parameters) {
        if (!parameters) {
            parameters = [{ type: "recent", value: 1 }];
        }
        console.log("native", "chatSelector");
        this.notificationNative("CallChatSelector", parameters);
    };
    /**
     @description 发起私聊消息
     @param chatType: {1: 私聊消息, 2: 群聊}
     @param format: {0: 文本消息, 1: 图片消息}
     @param to: 给谁发消息 数组
     @param message: 文字消息内容， 如果是图片消息则写 ""
     @param imageUrl: 图片消息需要填写 图片CDN地址url
     */
    NativeBase.prototype.privateChat = function (chatType, format, to, message, imageUrl) {
        console.log("native", "privateChat");
        var msgBody = {};
        var body = {};
        msgBody.body = body;
        if (format == 0) { //文本消息
            body.message = message;
            msgBody.bizType = 1;
            msgBody.format = 0;
            msgBody.msgType = 0;
        }
        else if (format == 1) {
            body.isEmoji = 0;
            body.urlLarge = imageUrl;
            body.thumbnailUrl = imageUrl + "?imageView/2/w/200/h/200";
            msgBody.bizType = 1;
            msgBody.format = 1;
            msgBody.msgType = 0;
        }
        msgBody.chatType = chatType;
        msgBody.offlineFlg = 1;
        msgBody.from = cc.uid;
        msgBody.ackFlg = 1;
        msgBody.offline = 1;
        msgBody.bubble = 0;
        msgBody.pushFlg = 1;
        msgBody.time = new Date().getTime();
        msgBody.v = 1;
        for (var i = 0, length_1 = to.length; i < length_1; i++) {
            msgBody.to = to[i];
            this.notificationNative("SendPrivateChat", msgBody);
        }
    };
    //NativeCallback---------------------------------------------------------------------------------------------------------------------------------------
    /**
     @description 收到mqtt消息
     */
    NativeBase.prototype.onPrivateMqttMsg = function (data) {
        console.log("native", "onPrivateMqttMsg", JSON.stringify(data));
        var message = JSON.parse(data.message);
        message.body = message.body || {};
        message.body.cmd = message.cmd;
        for (var i = 0; i < this.listeners.length; i++) {
            this.listeners[i].onMsg(data.topic, message.body, message.desc);
        }
    };
    /**
     @description 文件保存到CDN回调
     */
    NativeBase.prototype.saveFileToCDNResult = function (data) {
        console.log("native", "saveFileToCDNResult", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onSaveFileToCDNResult) {
                this.listeners[i].onSaveFileToCDNResult(data);
            }
        }
    };
    /**
     @description 更换mqtt接口地址返回信息
     */
    NativeBase.prototype.onChangeMqttHostPortResult = function (data) {
        console.log("native", "onChangeMqttHostPortResult", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onChangeMqttHostPortResult) {
                this.listeners[i].onChangeMqttHostPortResult(data);
            }
        }
    };
    /**
     @description 拿到H5票回调
     */
    NativeBase.prototype.onGetH5Ticket = function (data) {
        console.log("native", "onGetH5Ticket", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetH5Ticket) {
                this.listeners[i].onGetH5Ticket(data);
            }
        }
    };
    /**
     @description 私聊选择器回调
     */
    NativeBase.prototype.onGetSelectorResult = function (data) {
        console.log("native", "onGetSelectorResult", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetSelectorResult) {
                this.listeners[i].onGetSelectorResult(data);
            }
        }
    };
    /**
     @description 私聊消息回执
     */
    NativeBase.prototype.onGetPrivateChatResult = function (data) {
        console.log("native", "onGetSelectorResult", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetPrivateChatResult) {
                this.listeners[i].onGetPrivateChatResult(data);
            }
        }
    };
    /**
     @description 音效开关
     */
    NativeBase.prototype.onRoomSoundSwitch = function (data) {
        console.log("native", "onRoomSoundSwitch", (data.soundOn));
        //data.soundOn = data.soundOn || !data.musicMute;
        cc.soundOn = data.soundOn;
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onRoomSoundSwitch) {
                this.listeners[i].onRoomSoundSwitch(data);
            }
        }
    };
    /**
     @description 音效开关
     */
    NativeBase.prototype.onRoomSoundSwitchToJs = function (data) {
        console.log("native", "onRoomSoundSwitchToJs", data);
        cc.soundSwitch = data;
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onRoomSoundSwitchToJs) {
                this.listeners[i].onRoomSoundSwitchToJs(data);
            }
        }
    };
    /**
     @description 生命周期 - 回到前台回调
     */
    NativeBase.prototype.onGameResume = function (data) {
        console.log("native", "onGameResume", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onResume) {
                this.listeners[i].onResume(data);
            }
        }
    };
    /**
     @description 生命周期 - 退到后台回调
     */
    NativeBase.prototype.onGameStop = function (data) {
        console.log("native", "onGameStop", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGameStop) {
                this.listeners[i].onGameStop(data);
            }
        }
    };
    /**
     @description
     */
    NativeBase.prototype.onResetSound = function (data) {
        console.log("native", "onResetSound", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onResetSound) {
                this.listeners[i].onResetSound(data);
            }
        }
    };
    /**
     @description 充值成功
     */
    NativeBase.prototype.onRechargeSuccess = function (data) {
        console.log("native", "onRechargeSuccess", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onRechargeSuccess) {
                this.listeners[i].onRechargeSuccess(data);
            }
        }
    };
    /**
     @description
     */
    NativeBase.prototype.onPingFinish = function (data) {
        console.log("native", "onPingFinish", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onPingFinish) {
                this.listeners[i].onPingFinish(data);
            }
        }
    };
    /**
     @description 聊天
     */
    NativeBase.prototype.onRoomChat = function (data) {
        console.log("native", "onRoomChat", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onRoomChat) {
                this.listeners[i].onRoomChat(data);
            }
        }
    };
    /**
     @description 语音回调
     */
    NativeBase.prototype.onLiveVoiceVolume = function (data) {
        console.log("native", "onLiveVoiceVolume", JSON.stringify(data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onLiveVoiceVolume) {
                this.listeners[i].onLiveVoiceVolume(data);
            }
        }
    };
    /**
     @description 麦克风权限回调
     */
    NativeBase.prototype.onMicAuthorityResponse = function (data) {
        console.log("native", "onMicAuthorityResponse", (data));
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onMicAuthorityResponse) {
                this.listeners[i].onMicAuthorityResponse(data);
            }
        }
    };
    /**
     @description mqtt错误
     */
    NativeBase.prototype.onMqttError = function (err) {
        console.log("native", "onMqttError");
        this.showToastView("网络断开了");
    };
    /**
     @description mqtt重连
     */
    NativeBase.prototype.onMqttStateChange = function (data) {
        console.log("native", "onMqttStateChange");
        if (data.connected) {
            this.showToastView("网络恢复了");
            for (var i = 0; i < this.listeners.length; i++) {
                if (this.listeners[i].onMqttStateChange) {
                    this.listeners[i].onMqttStateChange(data);
                }
            }
        }
    };
    /**
     @description 被踢出房间
     @deprecated
     */
    NativeBase.prototype.onKickOutGame = function (data) {
        console.log("native", "onKickOutGame");
        // for (let i = 0; i < this.listeners.length; i++) {
        //     if (this.listeners[i].onKickOutGame) {
        //         this.listeners[i].onKickOutGame(data);
        //     }
        // }
    };
    /**
     @description 兑换道具成功回调
     */
    NativeBase.prototype.onExchange = function (data) {
        console.log("native", "onExchange");
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onExchange) {
                this.listeners[i].onExchange(data);
            }
        }
    };
    /**
     @description 输入框游戏频道输入回调
     */
    NativeBase.prototype.onKeyboardInput = function (data) {
        console.log("native", "onKeyboardInput");
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onKeyboardInput) {
                this.listeners[i].onKeyboardInput(data);
            }
        }
    };
    /**
     @description 回调关闭cocos个人信息面板（只是隐藏中间的个人信息部分，不隐藏后面的可点击透明蒙层）
     */
    NativeBase.prototype.onUserInfoPanelClose = function (data) {
        console.log("native", "onUserInfoPanelClose");
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onUserInfoPanelClose) {
                this.listeners[i].onUserInfoPanelClose(data);
            }
        }
    };
    /**
     * @description 原生主动关闭礼物面板，通知cocos，整体关闭个人信息面板，version == 31 新增接口
     * @param data {}
     */
    NativeBase.prototype.onNativeCloseGiftPanel = function (data) {
        console.log("native", "onNativeCloseGiftPanel");
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onNativeCloseGiftPanel) {
                this.listeners[i].onNativeCloseGiftPanel(data);
            }
        }
    };
    /**
     @description 原生通知cocos获取好友列表的结果
     */
    NativeBase.prototype.onGetBatchFriend = function (data) {
        console.log("native", "onGetBatchFriend", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetBatchFriend) {
                this.listeners[i].onGetBatchFriend(data);
            }
        }
    };
    /**
     @description
     */
    NativeBase.prototype.onGetNativeGlobalConfig = function (data) {
        console.log("native", "onGetNativeGlobalConfig", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetNativeGlobalConfig) {
                this.listeners[i].onGetNativeGlobalConfig(data);
            }
        }
    };
    NativeBase.prototype.onHttpResponse = function (data) {
        console.log("native", "onHttpResponse", data);
        //DO IN SUBCLASS
    };
    /**
     @description 加入语音房间回调
     */
    NativeBase.prototype.onJoinLiveVoiceRoomResult = function (data) {
        console.log("native", "onJoinLiveVoiceRoomResult", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onJoinLiveVoiceRoomResult) {
                this.listeners[i].onJoinLiveVoiceRoomResult(data);
            }
        }
    };
    /**
     @description 退出语音房间回调
     */
    NativeBase.prototype.onQuitLiveVoiceRoomResult = function (data) {
        console.log("native", "onQuitLiveVoiceRoomResult", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onQuitLiveVoiceRoomResult) {
                this.listeners[i].onQuitLiveVoiceRoomResult(data);
            }
        }
    };
    /**
     @description 私聊键盘回调
     */
    NativeBase.prototype.onGetKeyboardRes = function (data) {
        console.log("native", "onGetKeyboardRes", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetKeyboardRes) {
                this.listeners[i].onGetKeyboardRes(data);
            }
        }
    };
    /**
     @description 快捷兑换 / 支付 结果回调
    */
    NativeBase.prototype.onGetSceneShortCutPayRes = function (data) {
        console.log("native", "onGetSceneShortCutPayRes", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetSceneShortCutPayRes) {
                this.listeners[i].onGetSceneShortCutPayRes(data);
            }
        }
    };
    /**
     @description 获取 ABTest 配置
    */
    NativeBase.prototype.onGetABTestConfigRes = function (data) {
        console.log("native", "onGetABTestConfigRes", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onGetABTestConfigRes) {
                this.listeners[i].onGetABTestConfigRes(data);
            }
        }
    };
    /**
        @description 原生弹幕点击回调
    */
    NativeBase.prototype.onClickBarrageRes = function (data) {
        console.log("native", "onClickBarrageRes", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onClickBarrageRes) {
                this.listeners[i].onClickBarrageRes(data);
            }
        }
    };
    /**
     @description 游戏中H5窗口关闭，通知cocos
     */
    NativeBase.prototype.onH5CloseInGame = function (data) {
        console.log("native", "onH5CloseInGame", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onH5CloseInGame) {
                this.listeners[i].onH5CloseInGame(data);
            }
        }
    };
    /**
     @description H5给cocos发消息
     * message是由Object转成的字符串，Object结构如下：
     * {
     *   action: string,// 发的消息的名字，功能相当于cmd
     *   body: {}
     * }
     */
    NativeBase.prototype.onH5ToCocosMessage = function (data) {
        console.log("native", "onH5ToCocosMessage", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onH5ToCocosMessage) {
                this.listeners[i].onH5ToCocosMessage(data);
            }
        }
    };
    return NativeBase;
}());

/**
 * Created by goes_by on 2018/10/16.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var NativeAndroid = /** @class */ (function (_super) {
    __extends(NativeAndroid, _super);
    function NativeAndroid() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.cmdList = [];
        return _this;
    }
    NativeAndroid.prototype.register = function () {
        var that = this;
        cc.director.notificationJsGame = function (eventName, data) {
            console.log("cc.director.notificationJsGame", eventName);
            // console.log("cc.director.notificationJsGame push list");
            that.cmdList.push({
                eventName: eventName,
                data: data,
            });
        };
        cc.director.getScheduler().schedule(function () {
            for (var i = 0; i < 200 && that.cmdList.length > 0; i++) {
                var cmdData = that.cmdList.shift();
                that.dispatchNotification(cmdData.eventName, cmdData.data);
            }
        }, that, 0, 500 * 365 * 24 * 3600 * 60, 0);
    };
    /**
     @description http回调
     */
    NativeAndroid.prototype.onHttpResponse = function (data) {
        console.log("native", "onHttpResponse", data);
        for (var i = 0; i < this.listeners.length; i++) {
            if (this.listeners[i].onHttpResponse) {
                this.listeners[i].onHttpResponse(data.sign, JSON.parse(data.data));
            }
        }
    };
    return NativeAndroid;
}(NativeBase));
cc.native = new NativeAndroid();
cc.native.init();
