package com.wanba.mqttlib.processor;


import com.google.auto.service.AutoService;

import java.io.IOException;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.annotation.processing.AbstractProcessor;
import javax.annotation.processing.Filer;
import javax.annotation.processing.ProcessingEnvironment;
import javax.annotation.processing.Processor;
import javax.annotation.processing.RoundEnvironment;
import javax.lang.model.element.Element;
import javax.lang.model.element.ExecutableElement;
import javax.lang.model.element.TypeElement;
import javax.tools.JavaFileObject;


@AutoService(Processor.class)
public class MqttProcessor extends AbstractProcessor {

    Filer filer;
    Map<String, HashSet<String>> cmdMaps; // 命令 方法 关系映射，一个命令可以对应多个方法

    @Override
    public synchronized void init(ProcessingEnvironment processingEnvironment) {
        super.init(processingEnvironment);
        filer = processingEnvironment.getFiler();
        cmdMaps = new HashMap<>();
    }

    @Override
    public boolean process(Set<? extends TypeElement> set, RoundEnvironment roundEnvironment) {
        Set<? extends Element> elements = roundEnvironment.getElementsAnnotatedWith(Mqtt.class);

        StringBuilder builder = new StringBuilder()
                .append("package com.wanba.mqttlib.processor;\n\n")
                .append("import java.lang.reflect.Method;\n\n")
                .append("public class MqttEventBus")
                .append(" {\n\n")
                .append("\t private static MqttEventBus mqttEventBus;\n")
                .append("\t private MqttEventBus() {}\n\n")
                .append("\t public static MqttEventBus getInstance() {\n"
                        + "        if (null == mqttEventBus) {\n"
                        + "            synchronized (MqttEventBus.class) {\n"
                        + "                if (null == mqttEventBus) {\n"
                        + "                    mqttEventBus = new MqttEventBus();\n"
                        + "                }\n"
                        + "            }\n"
                        + "        }\n"
                        + "        return mqttEventBus;\n"
                        + "     }\n\n")
                .append("\t public void postMessage(Object object, String cmd, Object mqttRevMessage){\n"
                        + "        try {\n"
                        + "            Class clazz = object.getClass();\n");

        for (Element element : elements) {
            Mqtt mqtt = element.getAnnotation(Mqtt.class);
            if (null != mqtt.cmdList() && mqtt.cmdList().length > 0) {
                for (String cmd : mqtt.cmdList()) {
                    addIf(element, builder, cmd);
                }
            } else {
                addIf(element, builder, mqtt.cmd());
            }
        }

        builder.append("\t\t } catch (Exception e) {\n"
                + "            e.printStackTrace();\n"
                + "        }\n"
                + "    }\n"
                + "\n"
                + "private void invokeMethod(Object object, Object mqttRevMessage, String methodName, int paramsSize){\n"
                + "        Class clazz = object.getClass();\n"
                + "        boolean havaInvoke = false;\n"
                + "        try {\n"
                + "            Method[] methods = clazz.getMethods();\n"
                + "            if (methods.length == 0) return;\n"
                + "            for (Method method1 : methods) {\n"
                + "                if (method1.getName().equals(methodName)) {\n"
                + "                    if (paramsSize == 1) {\n"
                + "                        method1.setAccessible(true);\n"
                + "                        method1.invoke(object, mqttRevMessage);\n"
                + "                    } else {\n"
                + "                        method1.setAccessible(true);\n"
                + "                        method1.invoke(object, new Object[0]);\n"
                + "                    }\n"
                + "                    havaInvoke = true;\n"
                + "                    break;\n"
                + "                }\n"
                + "            }\n"
                + "            if (!havaInvoke) {\n"
                + "                Method[] declaredMethods = clazz.getDeclaredMethods();\n"
                + "                for (Method method : declaredMethods) {\n"
                + "                    if (method.getName().equals(methodName)) {\n"
                + "                        if (paramsSize == 1) {\n"
                + "                            method.setAccessible(true);\n"
                + "                            method.invoke(object, mqttRevMessage);\n"
                + "                        } else {\n"
                + "                            method.setAccessible(true);\n"
                + "                            method.invoke(object, new Object[0]);\n"
                + "                        }\n"
                + "                        break;\n"
                + "                    }\n"
                + "                }\n"
                + "            }\n"
                + "        } catch (Exception e) {\n"
                + "            e.printStackTrace();\n"
                + "        }\n"
                + "    }"
                + "}");

        try {
            JavaFileObject source = filer.createSourceFile("com.wanba.mqttlib.processor.MqttEventBus");
            Writer writer = source.openWriter();
            writer.write(builder.toString());
            writer.flush();
            writer.close();
        } catch (IOException e) {
        }
        return false;
    }

    private void addIf(Element element, StringBuilder builder, String cmd) {
        String name = element.getSimpleName().toString();
        ExecutableElement typeElement = (ExecutableElement) element;
        int size = typeElement.getParameters().size();
        if (null != cmdMaps.get(cmd) && cmdMaps.get(cmd).contains(name)) {
            return;
        }
        HashSet<String> hashSet = cmdMaps.get(cmd);
        if (null == hashSet) {
            hashSet = new HashSet<>();
        }
        hashSet.add(name);
        cmdMaps.put(cmd, hashSet);
        builder.append("\t\t\tif (\"" + cmd + "\".equals(cmd)) {\n"
                + "                invokeMethod(object,mqttRevMessage,\"" + name + "\"," + size + ");\n"
                + "            }\n");
    }

    @Override
    public Set<String> getSupportedAnnotationTypes() {
        return Collections.singleton(Mqtt.class.getCanonicalName());
    }
}